==> cxf-services-xkms-common-3.3.11-sources.jar: org/apache/cxf/xkms/model/xkms/AuthenticationType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for AuthenticationType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="AuthenticationType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}KeyBindingAuthentication" minOccurs="0"/&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}NotBoundAuthentication" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AuthenticationType", propOrder = {
    "keyBindingAuthentication",
    "notBoundAuthentication"
})
public class AuthenticationType {

    @XmlElement(name = "KeyBindingAuthentication")
    protected KeyBindingAuthenticationType keyBindingAuthentication;
    @XmlElement(name = "NotBoundAuthentication")
    protected NotBoundAuthenticationType notBoundAuthentication;

    /**
     * Gets the value of the keyBindingAuthentication property.
     * 
     * @return
     *     possible object is
     *     {@link KeyBindingAuthenticationType }
     *     
     */
    public KeyBindingAuthenticationType getKeyBindingAuthentication() {
        return keyBindingAuthentication;
    }

    /**
     * Sets the value of the keyBindingAuthentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link KeyBindingAuthenticationType }
     *     
     */
    public void setKeyBindingAuthentication(KeyBindingAuthenticationType value) {
        this.keyBindingAuthentication = value;
    }

    /**
     * Gets the value of the notBoundAuthentication property.
     * 
     * @return
     *     possible object is
     *     {@link NotBoundAuthenticationType }
     *     
     */
    public NotBoundAuthenticationType getNotBoundAuthentication() {
        return notBoundAuthentication;
    }

    /**
     * Sets the value of the notBoundAuthentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link NotBoundAuthenticationType }
     *     
     */
    public void setNotBoundAuthentication(NotBoundAuthenticationType value) {
        this.notBoundAuthentication = value;
    }

}

==> cxf-services-xkms-common-4.0.3-sources.jar: org/apache/cxf/xkms/model/xkms/AuthenticationType.java <==

package org.apache.cxf.xkms.model.xkms;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for AuthenticationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AuthenticationType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}KeyBindingAuthentication" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}NotBoundAuthentication" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AuthenticationType", propOrder = {
    "keyBindingAuthentication",
    "notBoundAuthentication"
})
public class AuthenticationType {

    @XmlElement(name = "KeyBindingAuthentication")
    protected KeyBindingAuthenticationType keyBindingAuthentication;
    @XmlElement(name = "NotBoundAuthentication")
    protected NotBoundAuthenticationType notBoundAuthentication;

    /**
     * Gets the value of the keyBindingAuthentication property.
     * 
     * @return
     *     possible object is
     *     {@link KeyBindingAuthenticationType }
     *     
     */
    public KeyBindingAuthenticationType getKeyBindingAuthentication() {
        return keyBindingAuthentication;
    }

    /**
     * Sets the value of the keyBindingAuthentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link KeyBindingAuthenticationType }
     *     
     */
    public void setKeyBindingAuthentication(KeyBindingAuthenticationType value) {
        this.keyBindingAuthentication = value;
    }

    /**
     * Gets the value of the notBoundAuthentication property.
     * 
     * @return
     *     possible object is
     *     {@link NotBoundAuthenticationType }
     *     
     */
    public NotBoundAuthenticationType getNotBoundAuthentication() {
        return notBoundAuthentication;
    }

    /**
     * Sets the value of the notBoundAuthentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link NotBoundAuthenticationType }
     *     
     */
    public void setNotBoundAuthentication(NotBoundAuthenticationType value) {
        this.notBoundAuthentication = value;
    }

}
